# jiramenu

# installation

## pip

```
pip install jiramenu
```

## aur

you can use your favourite aur helper to install `python-jiramenu-git`. for example
```
yay -S python-jiramenu-git
```

# usage

jiramenu expects a config file in your home directory called `.jiramenu`. To generate one just run:

```
jiramenu copy-config
```

after editing the file to fit your needs you can the following command to show the frontend

```
jiramenu show
```
